Documentation
¶
Index ¶
Constants ¶
const Version = "1.1.5"
Version is the current version of ZenoEngine
Variables ¶
This section is empty.
Functions ¶
func EnsureJWTSecret ¶
func EnsureJWTSecret()
EnsureJWTSecret checks if JWT_SECRET is set. If not, it automatically generates one, updates the .env file, and sets the env var for the current process.
func HandleCheck ¶
func HandleCheck(args []string)
func HandleKeyGenerate ¶
func HandleKeyGenerate()
HandleKeyGenerate generates a new key and updates/saves it to the .env file.
func HandleMakeAuth ¶
func HandleMakeAuth()
func HandleMigrate ¶
func HandleMigrate()
func HandleNew ¶
func HandleNew(args []string)
HandleNew creates a new ZenoEngine project from embedded templates
func HandleRollback ¶
func HandleRollback()
func HandleTest ¶
func HandleTest(args []string)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.